module DiffTest where

import ElmTest.Assertion (..)
import ElmTest.Test (..)

import Diff (..)

type TestType
  = Foo Int
  | Bar String

suite = Suite "Foo"
  [ test "diffLines" <|
      diffLines "a\nb\nc" "a\nb1\nxxx\n"
      `assertEqual`
      [ NoChange "a\n"
      , Changed "b\nc" "b1\nxxx\n"
      ]
  , test "diffChars" <|
      diffChars "a\nb\nc" "a\nb1\nxxx\n"
      `assertEqual`
      [ NoChange "a\nb"
      , Added "1"
      , NoChange "\n"
      , Changed "c" "xxx\n"
      ]
  , test "empty strings" <|
      diffChars "" ""
      `assertEqual`
      []
  , test "single char is added" <|
      diffChars "" "b"
      `assertEqual`
      [ Added "b" ]
  , test "single char is removed" <|
      diffChars "a" ""
      `assertEqual`
      [ Removed "a" ]
  , test "single char that is equal" <|
      diffChars "a" "a"
      `assertEqual`
      [ NoChange "a" ]
  , test "single char that is changed" <|
      diffChars "a" "b"
      `assertEqual`
      [ Changed "a" "b" ]
  , test "second char is added" <|
      diffChars "a" "ab"
      `assertEqual`
      [ NoChange "a"
      , Added "b"
      ]
  , test "second char is equal" <|
      diffChars "ab" "1b"
      `assertEqual`
      [ Changed "a" "1"
      , NoChange "b"
      ]
  , test "two chars are equal" <|
      diffChars "ab" "ab"
      `assertEqual`
      [ NoChange "ab" ]
  , test "two chars are changed" <|
      diffChars "ab" "12"
      `assertEqual`
      [ Changed "ab" "12" ]
  , test "two chars are added" <|
      diffChars "" "ab"
      `assertEqual`
      [ Added "ab" ]
  , test "two chars are removed" <|
      diffChars "ab" ""
      `assertEqual`
      [ Removed "ab" ]
  , test "first char is removed" <|
      diffChars "ab" "b"
      `assertEqual`
      [ Removed "a"
      , NoChange "b"
      ]
  ]
